@@ -7,13 +7,13 @@ from w3bsite.classes import utils, views
 from w3bsite.classes import defaults as _defaults_
 
 # the payments views.
-class Views(_defaults_.Defaults):
+class Views(_defaults_.dev0s.defaults.):
 	def __init__(self, 
 		# passed Website.x objects.
 		defaults=None,
 	):
 		# defaults.
-		_defaults_.Defaults.__init__(self)
+		_defaults_.dev0s.defaults.__init__(self)
 		self.assign(defaults.dict())
 		
 		# urlpatterns.
@@ -25,7 +25,7 @@ class Views(_defaults_.Defaults):
 	# purchase.
 	class Purchase(views.View):
 		def __init__(self, defaults=None):
-			_defaults_.Defaults.__init__(self)
+			_defaults_.dev0s.defaults.__init__(self)
 			self.assign(defaults.dict())
 			views.View.__init__(self, "payments/", "purchase", template_data=self.template_data, html=f"w3bsite/classes/apps/payments/html/purchase.html")
 		def view(self, request):
@@ -35,7 +35,7 @@ class Views(_defaults_.Defaults):
 	# cancel.
 	class Cancel(views.View):
 		def __init__(self, defaults=None):
-			_defaults_.Defaults.__init__(self)
+			_defaults_.dev0s.defaults.__init__(self)
 			self.assign(defaults.dict())
 			views.View.__init__(self, "payments/", "cancel", template_data=self.template_data, html=f"w3bsite/classes/apps/payments/html/cancel.html")
 		def view(self, request):
