@@ -7,7 +7,7 @@ from w3bsite.classes import utils
 
 # the deployment object class.
 class Deployment(Object):
-	# does not use Defaults so also accessable without Website init.
+	# does not use dev0s.defaults. so also accessable without Website init.
 	# deploy the website on a local ubuntu machine.
 	def __init__(self,
 		# the root path.
@@ -78,13 +78,13 @@ class Deployment(Object):
 		for i in ["gunicorn.socket", "gunicorn", "nginx"]:
 			command += f"sudo systemctl start {i} &&"
 		command = command[:-3]
-		response = Code.execute(command)
+		response = dev0s.code.execute(command)
 		if not response.success: return response
 		output = response.output
 		if output in ["", "\n"]:
-			return Response.success(f"Successfully started {self.name}")
+			return dev0s.response.success(f"Successfully started {self.name}")
 		else:
-			return Response.error(f"Failed to started {self.name};\n{output}")
+			return dev0s.response.error(f"Failed to started {self.name};\n{output}")
 
 		#
 	def stop(self):
@@ -94,13 +94,13 @@ class Deployment(Object):
 		for i in ["gunicorn.socket", "gunicorn", "nginx"]:
 			command += f"sudo systemctl stop {i} &&"
 		command = command[:-3]
-		response = Code.execute(command)
+		response = dev0s.code.execute(command)
 		if not response.success: return response
 		output = response.output
 		if output in ["", "\n"]:
-			return Response.success(f"Successfully stopped {self.name}")
+			return dev0s.response.success(f"Successfully stopped {self.name}")
 		else:
-			return Response.error(f"Failed to stopped {self.name};\n{output}")
+			return dev0s.response.error(f"Failed to stopped {self.name};\n{output}")
 
 		#
 	def restart(self):
@@ -110,22 +110,22 @@ class Deployment(Object):
 		for i in ["gunicorn.socket", "gunicorn", "nginx"]:
 			command += f"sudo systemctl restart {i} &&"
 		command = command[:-3]
-		response = Code.execute(command)
+		response = dev0s.code.execute(command)
 		if not response.success: return response
 		output = response.output
 		if output in ["", "\n"]:
-			return Response.success(f"Successfully restarted {self.name}")
+			return dev0s.response.success(f"Successfully restarted {self.name}")
 		else:
-			return Response.error(f"Failed to restarted {self.name};\n{output}")
+			return dev0s.response.error(f"Failed to restarted {self.name};\n{output}")
 
 		#
 	def status(self):
 
 		# execute.
-		response = Code.execute("sudo systemctl status gunicorn > /tmp/status && cat /tmp/status && rm -fr /tmp/status")
+		response = dev0s.code.execute("sudo systemctl status gunicorn > /tmp/status && cat /tmp/status && rm -fr /tmp/status")
 		if not response.success: return response
 		status = response.output
-		return Response.success(f"Successfully parsed the status of {self.name}.", {
+		return dev0s.response.success(f"Successfully parsed the status of {self.name}.", {
 			"status":status,
 		})
 
@@ -137,7 +137,7 @@ class Deployment(Object):
 		Files.save(f"{self.database}/logs/errors", "")
 		Files.save(f"{self.database}/logs/nginx", "")
 		Files.save(f"{self.database}/logs/nginx.debug", "")
-		return Response.success("Successfully resetted the logs.")
+		return dev0s.response.success("Successfully resetted the logs.")
 
 		#
 	def tail(self, nginx=False, debug=False):
@@ -155,7 +155,7 @@ class Deployment(Object):
 				data = Files.load(f"{self.database}/logs/errors")
 		
 		# handler.
-		return Response.success(f"Successfully tailed the {self.name} logs.", {
+		return dev0s.response.success(f"Successfully tailed the {self.name} logs.", {
 			"logs":data,
 		})
 
@@ -166,7 +166,7 @@ class Deployment(Object):
 		
 		# check arguments.
 		if self.remote in ["vps"]:
-			response = Response.parameters.check(
+			response = dev0s.response.parameters.check(
 				traceback=self.__traceback__(function="configure"),
 				parameters={
 					"vps_ip":self.vps_ip,
@@ -175,7 +175,7 @@ class Deployment(Object):
 			if not response.success: return response
 			username = self.vps_username
 		else:
-			username = Defaults.vars.user
+			username = dev0s.defaults.vars.user
 		
 		# configure before loader.
 		if self.live:
@@ -184,33 +184,33 @@ class Deployment(Object):
 			if not Files.exists(f"{self.database}/tls/dhparam.pem"):
 				if loader != None: loader.hold()
 				tmp = "/tmp/dhparam.pem"
-				os.system(f"sudo openssl dhparam -out {tmp} 4096 && sudo chown {Defaults.vars.user}:{Defaults.vars.group} {tmp} && mv {tmp} {self.database}/tls/dhparam.pem && sudo chown {Defaults.vars.user}:{Defaults.vars.group} {self.database}/tls/dhparam.pem")
+				os.system(f"sudo openssl dhparam -out {tmp} 4096 && sudo chown {dev0s.defaults.vars.user}:{dev0s.defaults.vars.group} {tmp} && mv {tmp} {self.database}/tls/dhparam.pem && sudo chown {dev0s.defaults.vars.user}:{dev0s.defaults.vars.group} {self.database}/tls/dhparam.pem")
 				if loader != None: loader.release()
 
 		# loader.
-		if log_level >= 0: loader = Console.Loader(f"Configuring deployment of website {self.domain} ...")
+		if log_level >= 0: loader = dev0s.console.Loader(f"Configuring deployment of website {self.domain} ...")
 
 		# check remote.
 		if self.remote in ["heroku"]:
 			if log_level >= 0: loader.stop(success=False)
-			return Response.error(f"You can not execute function <Website.deployment.configure> with remote [{self.remote}].")
+			return dev0s.response.error(f"You can not execute function <Website.deployment.configure> with remote [{self.remote}].")
 
 		# os.
 		if OS not in ["macos", "linux"]: 
 			if log_level >= 0: loader.stop(success=False)
-			return Response.error(f"Unsupported operating system [{OS}].")
+			return dev0s.response.error(f"Unsupported operating system [{OS}].")
 
 		# requirements.
 		if not Files.exists(f"{self.root}/requirements"): os.mkdir(f"{self.root}/requirements")
 		if not Files.exists(f"{self.root}/requirements/requirements.pip"): 
-			Files.save(f"{self.root}/requirements/requirements.pip", "wheel\nuwsgi\ngunicorn\nwhitenoise\ndjango\npsycopg2-binary\nsyst3m\nw3bsite")
+			Files.save(f"{self.root}/requirements/requirements.pip", "wheel\nuwsgi\ngunicorn\nwhitenoise\ndjango\npsycopg2-binary\ndev0s\nw3bsite")
 		if not Files.exists(f"{self.root}/requirements/installer"): 
 			os.system(f"cp {SOURCE_PATH}/example/requirements/installer {self.root}/requirements/installer && chmod +x {self.root}/requirements/installer")
 
 		# favicon.
 		if self.live:
 			if not Files.exists(f"{self.root}/__defaults__/static/favicon.ico"):
-				response = Code.execute(f"curl -s https://raw.githubusercontent.com/vandenberghinc/public-storage/master/w3bsite/favicon.ico -o {self.root}/__defaults__/static/favicon.ico")
+				response = dev0s.code.execute(f"curl -s https://raw.githubusercontent.com/vandenberghinc/public-storage/master/w3bsite/favicon.ico -o {self.root}/__defaults__/static/favicon.ico")
 				if not response.success: return response
 				output = response.output
 
@@ -225,7 +225,7 @@ class Deployment(Object):
 		# database.
 		if self.live:
 			if not Files.exists(self.database): 
-				os.system(f"sudo mkdir -p {self.database} && sudo chown {Defaults.vars.user}:{Defaults.vars.group} {self.database} && sudo chmod 770 {self.database}")
+				os.system(f"sudo mkdir -p {self.database} && sudo chown {dev0s.defaults.vars.user}:{dev0s.defaults.vars.group} {self.database} && sudo chmod 770 {self.database}")
 			if not Files.exists(f"{self.database}/logs"): Files.create(f"{self.database}/logs", directory=True)
 
 		# deployment.
@@ -236,7 +236,7 @@ class Deployment(Object):
 			"***USER***":username, 
 			"***DOMAIN***":self.domain,
 			"***DATABASE***":self.database,
-			"***USER***":Defaults.vars.user,
+			"***USER***":dev0s.defaults.vars.user,
 			"***WEBSITE_BASE***":gfp.base(SOURCE_PATH),
 		}
 		for path in Files.Directory(path=f"{SOURCE_PATH}/classes/deployment/lib/").paths():
@@ -252,7 +252,7 @@ class Deployment(Object):
 		
 		# success.
 		if log_level >= 0: loader.stop()
-		return Response.success(f"Successfully configured the deployment of domain {self.domain}.")
+		return dev0s.response.success(f"Successfully configured the deployment of domain {self.domain}.")
 
 		#
 	# deploy is for remote:local only. 
@@ -260,28 +260,28 @@ class Deployment(Object):
 			
 		# loader.
 		loader = None
-		if log_level >= 0: loader = Console.Loader(f"Deploying domain {self.domain} ...")
+		if log_level >= 0: loader = dev0s.console.Loader(f"Deploying domain {self.domain} ...")
 
 		# check namecheap domain.
 		if not (self.remote in ["vps"] and self.live):
 			response = self.namecheap.check_domain(self.namecheap.post_domain)
 			if response.error != None: 
 				if log_level >= 0: loader.stop(success=False)
-				Response.log(response=response, log_level=log_level)
+				dev0s.response.log(response=response, log_level=log_level)
 				return response
 			elif not response["exists"]:
 				if log_level >= 0: loader.stop(success=False)
-				return Response.error(f"Specified domain [{self.namecheap.post_domain}] is not owned by namecheap user [{self.namecheap.username}].", log_level=log_level)
+				return dev0s.response.error(f"Specified domain [{self.namecheap.post_domain}] is not owned by namecheap user [{self.namecheap.username}].", log_level=log_level)
 
 		# check remote.
 		if self.remote in ["vps"] and not self.live:
 			if log_level >= 0: loader.stop(success=False)
-			return Response.error(f"You can not execute function <Website.deployment.deploy> with remote [{self.remote}].")
+			return dev0s.response.error(f"You can not execute function <Website.deployment.deploy> with remote [{self.remote}].")
 
 		# os.
 		if OS not in ["linux"]: 
 			if log_level >= 0: loader.stop(success=False)
-			return Response.error(f"Unsupported operating system [{OS}].")
+			return dev0s.response.error(f"Unsupported operating system [{OS}].")
 		
 		# configure.
 		response = self.configure(reinstall=reinstall, log_level=log_level, loader=loader)
@@ -294,18 +294,18 @@ class Deployment(Object):
 		tls_domain = Files.load(f"{self.database}/tls/.domain").replace('\n',"")
 		if tls_domain != self.domain:
 			if log_level >= 0: loader.stop(success=False)
-			return Response.error(f"TLS Certificate mis match. Installed tls certificate [{self.database}/tls] is linked to domain {tls_domain}, not specified domain {self.domain}.", log_level=0)
+			return dev0s.response.error(f"TLS Certificate mis match. Installed tls certificate [{self.database}/tls] is linked to domain {tls_domain}, not specified domain {self.domain}.", log_level=0)
 		
 		# checks.
 		if not Files.exists(f"{self.database}/tls/server.key") or not Files.exists(f"{self.database}/tls/server.crt"):
 			if log_level >= 0: loader.stop(success=False)
-			return Response.error("No tls certificate exists.\nExecute the following command to generate a tls certificate:\n$ ./website.py --generate-tls", log_level=log_level)
+			return dev0s.response.error("No tls certificate exists.\nExecute the following command to generate a tls certificate:\n$ ./website.py --generate-tls", log_level=log_level)
 		#if not Files.exists(f"{self.database}/tls/signed.server.crt"):
 		#	if log_level >= 0: loader.stop(success=False)
-		#	return Response.error("No activated tls certificate exists. \nExecute the following command to activate the generated tls certificate:\n$ ./website.py --activate-tls", log_level=log_level)
+		#	return dev0s.response.error("No activated tls certificate exists. \nExecute the following command to activate the generated tls certificate:\n$ ./website.py --activate-tls", log_level=log_level)
 		#if not Files.exists(f"{self.database}/tls/server.ca-bundle"):
 		#	if log_level >= 0: loader.stop(success=False)
-		#	return Response.error("No bundled tls certificate exists. \nDownload the signed certificate send to your email, extr the zip to a directory and execute \n$ ./website.py --bundle-tls /path/to/extracted/directory/", log_level=log_level)
+		#	return dev0s.response.error("No bundled tls certificate exists. \nDownload the signed certificate send to your email, extr the zip to a directory and execute \n$ ./website.py --bundle-tls /path/to/extracted/directory/", log_level=log_level)
 		
 		# arguments.
 		arguments = ""
@@ -314,15 +314,15 @@ class Deployment(Object):
 		
 		# execute & handle.
 		Files.chmod(f"{self.root}/deployment/installer", "+x")
-		response = Code.execute(f"bash {self.root}/deployment/installer{arguments}")
+		response = dev0s.code.execute(f"bash {self.root}/deployment/installer{arguments}")
 		if not response.success:
 			#if "Error:" in output or ("nginx: the configuration file /etc/nginx/nginx.conf syntax is ok" not in output and "nginx: configuration file /etc/nginx/nginx.conf test is successful" not in output): #"Successfully deployed domain " not in output
 			print(response.output)
 			if log_level >= 0: loader.stop(success=False)
-			return Response.error(f"Failed to deploy website {self.domain}.", log_level=log_level)
+			return dev0s.response.error(f"Failed to deploy website {self.domain}.", log_level=log_level)
 		else:
 			if log_level >= 0: loader.stop()
-			return Response.success(f"Successfully deployed domain https://{self.domain}.", log_level=log_level)
+			return dev0s.response.success(f"Successfully deployed domain https://{self.domain}.", log_level=log_level)
 
 		#
 	def generate_tls(self, log_level=0):
@@ -336,11 +336,11 @@ class Deployment(Object):
 
 		# check duplicate.
 		if Files.exists(f"{self.database}/tls/server.key") or Files.exists(f"{self.database}/tls/server.crt"):
-			return Response.error("The tls certificate already exists.", log_level=log_level)
+			return dev0s.response.error("The tls certificate already exists.", log_level=log_level)
 
 		# generate.
-		if log_level >= 0: loader = Console.Loader("Generating a tls certificate ...")
-		response = Code.execute(f"""
+		if log_level >= 0: loader = dev0s.console.Loader("Generating a tls certificate ...")
+		response = dev0s.code.execute(f"""
 			cd {base}
 
 			# Generate a passphrase
@@ -369,26 +369,26 @@ class Deployment(Object):
 		if not Files.exists(f"{self.database}/tls/server.key") or not Files.exists(f"{self.database}/tls/server.crt"):
 			if log_level >= 0: loader.stop(success=False)
 			os.system(f"rm -fr {base}")
-			return Response.error(f"Failed to generate a tls certificate.", log_level=log_level)
+			return dev0s.response.error(f"Failed to generate a tls certificate.", log_level=log_level)
 		else:
 			if log_level >= 0: loader.stop()
 			Files.save(f"{self.database}/tls/.domain", self.domain)
-			return Response.success(f"Successfully generated a tls certificate.", log_level=log_level)
+			return dev0s.response.success(f"Successfully generated a tls certificate.", log_level=log_level)
 
 		#
 	def activate_tls(self, log_level=0):
 
 		# check existsance.
 		if not Files.exists(f"{self.database}/tls/server.key") or not Files.exists(f"{self.database}/tls/server.crt"):
-			return Response.error("No generated tls certificate exists.", log_level=log_level)
+			return dev0s.response.error("No generated tls certificate exists.", log_level=log_level)
 
 		# check duplicate.
 		if Files.exists(f"{self.database}/tls/signed.server.key"):
-			return Response.error("A signed tls certificate already exists.", log_level=log_level)
+			return dev0s.response.error("A signed tls certificate already exists.", log_level=log_level)
 
 		response = self.namecheap.get_tls()
 		if response.error != None: 
-			Response.log(response=response, log_level=log_level)
+			dev0s.response.log(response=response, log_level=log_level)
 			return response
 		tls, certificates = response["tls"], response["certificates"]
 		
@@ -396,13 +396,13 @@ class Deployment(Object):
 		if certificates == 0:
 
 			# create tls.
-			loader = Console.Loader("Purchasing a namecheap tls certificate ...")
+			loader = dev0s.console.Loader("Purchasing a namecheap tls certificate ...")
 			response = self.namecheap.create_tls(
 				# the expiration years.
 				years=2,
 				# the tls type.
 				type="PositiveSSL",)
-			Response.log(response=response, log_level=log_level)
+			dev0s.response.log(response=response, log_level=log_level)
 			if response.error != None: 
 				loader.stop(success=False)
 				return response	
@@ -412,7 +412,7 @@ class Deployment(Object):
 			response = self.namecheap.get_tls()
 			if response.error != None: 
 				loader.stop(success=False)
-				Response.log(response=response, log_level=log_level)
+				dev0s.response.log(response=response, log_level=log_level)
 				return response
 			loader.stop()
 			tls, certificates = response["tls"], response["certificates"]
@@ -434,13 +434,13 @@ class Deployment(Object):
 
 			# create certficiate on no new purchase found.
 			if id == None:
-				loader = Console.Loader("Purchasing a namecheap tls certificate ...")
+				loader = dev0s.console.Loader("Purchasing a namecheap tls certificate ...")
 				response = self.namecheap.create_tls(
 					# the expiration years.
 					years=2,
 					# the tls type.
 					type="PositiveSSL",)
-				Response.log(response=response, log_level=log_level)
+				dev0s.response.log(response=response, log_level=log_level)
 				if response.error != None: 
 					loader.stop(success=False)
 					return response	
@@ -448,62 +448,62 @@ class Deployment(Object):
 				id = response["certificate_id"]
 
 			# activate tls for root domain.
-			loader = Console.Loader("Activating tls certificate ...")
+			loader = dev0s.console.Loader("Activating tls certificate ...")
 			response = self.namecheap.activate_tls(
 				# the certificate's id.
 				certificate_id=id,)
 			loader.stop(success=response["success"])
-			Response.log(response=response, log_level=log_level)
+			dev0s.response.log(response=response, log_level=log_level)
 			if response.error != None: return response
 			
 		# handlers.
-		return Response.success(f"Successfully activated the tls certificate of domain [{self.domain}]. Wait for the CA to send you a .zip file with your signed certificate. Extract the zip & bundle the certificate with: $ ./website.py --bundle-tls /path/to/extracted/directory/certificate/", log_level=log_level)
+		return dev0s.response.success(f"Successfully activated the tls certificate of domain [{self.domain}]. Wait for the CA to send you a .zip file with your signed certificate. Extract the zip & bundle the certificate with: $ ./website.py --bundle-tls /path/to/extracted/directory/certificate/", log_level=log_level)
 
 		#
 	def bundle_tls(self, directory, log_level=0):
 		
 		# check dir.
 		if not Files.exists(directory):
-			return Response.error(f"Specified directory [{directory}] does not exist.", log_level=log_level)
+			return dev0s.response.error(f"Specified directory [{directory}] does not exist.", log_level=log_level)
 		if ".zip" in directory:
-			return Response.error(f"Specified directory [{directory}] is zip format, extract the zip first.", log_level=log_level)
+			return dev0s.response.error(f"Specified directory [{directory}] is zip format, extract the zip first.", log_level=log_level)
 		if not os.path.isdir(directory):
-			return Response.error(f"Specified directory [{directory}] is not a directory.", log_level=log_level)
+			return dev0s.response.error(f"Specified directory [{directory}] is not a directory.", log_level=log_level)
 		
 		# move x.crt to server.crt
 		if not Files.exists(f"{directory}/server.crt") and not Files.exists(f'{directory}/{self.domain.replace(".","_")}.crt'):
-			return Response.success(f'You must rename the [{directory}/{self.domain.replace(".","_")}.crt] file manually to [{directory}/server.crt] in order to proceed.', log_level=log_level)
+			return dev0s.response.success(f'You must rename the [{directory}/{self.domain.replace(".","_")}.crt] file manually to [{directory}/server.crt] in order to proceed.', log_level=log_level)
 		if not Files.exists(f"{directory}/server.crt") and Files.exists(f'{directory}/{self.domain.replace(".","_")}.crt'):
 			os.system(f'mv {directory}/{self.domain.replace(".","_")}.crt {directory}/server.crt')
 		if not Files.exists(f"{directory}/server.crt"):
-			return Response.success(f'Failed to rename the [{directory}/{self.domain.replace(".","_")}.crt] file to [{directory}/server.crt].', log_level=log_level)
+			return dev0s.response.success(f'Failed to rename the [{directory}/{self.domain.replace(".","_")}.crt] file to [{directory}/server.crt].', log_level=log_level)
 
 		# bundle ca.
-		response = Code.execute(f"""
-			cat {directory}/AAACertificateServices.crt {directory}/SectigoRSADomainValidationSecureServerCA.crt {directory}/Defaults.vars.userTrustRSAAAACA.crt > {self.database}/tls/server.ca-bundle
+		response = dev0s.code.execute(f"""
+			cat {directory}/AAACertificateServices.crt {directory}/SectigoRSADomainValidationSecureServerCA.crt {directory}/dev0s.defaults.vars.userTrustRSAAAACA.crt > {self.database}/tls/server.ca-bundle
 			cat {directory}/server.crt {self.database}/tls/server.ca-bundle > {self.database}/tls/signed.server.crt
 			mv {self.database}/tls/server.crt {self.database}/tls/original.server.crt
 			cp {self.database}/tls/signed.server.crt {self.database}/tls/server.crt
 			""")
 		if not response.success: return response
 		if Files.exists(f"{self.database}/tls/signed.server.crt"):
-			return Response.success(f"Successfully bundled ssl certificate [{directory}].", log_level=log_level)
+			return dev0s.response.success(f"Successfully bundled ssl certificate [{directory}].", log_level=log_level)
 		else:
-			return Response.error(f"Failed to bundle ssl certificate [{directory}].", log_level=log_level)
+			return dev0s.response.error(f"Failed to bundle ssl certificate [{directory}].", log_level=log_level)
 	def check_dns(self, log_level=0):
 
 		# loader.
-		if log_level >= 0: loader = Console.Loader(f"Checking dns settings of domain {self.domain} ...")
+		if log_level >= 0: loader = dev0s.console.Loader(f"Checking dns settings of domain {self.domain} ...")
 
 		# check namecheap domain.
 		response = self.namecheap.check_domain(self.namecheap.post_domain)
 		if response.error != None: 
 			if log_level >= 0: loader.stop(success=False)
-			Response.log(response=response, log_level=log_level)
+			dev0s.response.log(response=response, log_level=log_level)
 			return response
 		elif not response["exists"]:
 			if log_level >= 0: loader.stop(success=False)
-			return Response.error(f"Specified domain [{self.namecheap.post_domain}] is not owned by namecheap user [{self.namecheap.username}].", log_level=log_level)
+			return dev0s.response.error(f"Specified domain [{self.namecheap.post_domain}] is not owned by namecheap user [{self.namecheap.username}].", log_level=log_level)
 
 		# add dns records.
 		ip = NETWORK_INFO["public_ip"]
@@ -523,11 +523,11 @@ class Deployment(Object):
 			# the dns record value/address,
 			value=ip,)
 		if response.error != None and "] already exists." not in response.error: 
-			Response.log(response=response, log_level=log_level)
+			dev0s.response.log(response=response, log_level=log_level)
 			if log_level >= 0: loader.stop(success=False)
 			return response
 		elif response.error == None: 
-			Response.log(response=response, log_level=log_level)
+			dev0s.response.log(response=response, log_level=log_level)
 		response = self.namecheap.add_dns(
 			# the domain.
 			domain=self.namecheap.post_domain,
@@ -538,15 +538,15 @@ class Deployment(Object):
 			# the dns record value/address,
 			value=ip,)
 		if response.error != None and "] already exists." not in response.error: 
-			Response.log(response=response, log_level=log_level)
+			dev0s.response.log(response=response, log_level=log_level)
 			if log_level >= 0: loader.stop(success=False)
 			return response
 		elif response.error == None: 
-			Response.log(response=response, log_level=log_level)
+			dev0s.response.log(response=response, log_level=log_level)
 		
 		# handlers.
 		if log_level >= 0: loader.stop()
-		return Response.success(f"Successfully checked the deployment dns settings for domain {self.domain}.", log_level=log_level)
+		return dev0s.response.success(f"Successfully checked the deployment dns settings for domain {self.domain}.", log_level=log_level)
 
 		#
 
