@@ -10,11 +10,11 @@ import stripe
 
 # univeral functions.
 def __handle_stripe_exception__(exception):
-	if "Request req_" in f"{exception}": return Response.error(f"{exception}".split(": ")[1])
-	else: return Response.error(f"{exception}")
+	if "Request req_" in f"{exception}": return dev0s.response.error(f"{exception}".split(": ")[1])
+	else: return dev0s.response.error(f"{exception}")
 
 # the stripe object class_.
-class Stripe(_defaults_.Defaults):
+class Stripe(_defaults_.dev0s.defaults.):
 	# privacy policy generator.
 	# https://getterms.io/
 	def __init__(self,
@@ -37,7 +37,7 @@ class Stripe(_defaults_.Defaults):
 			notes=[], )
 
 		# defaults.
-		_defaults_.Defaults.__init__(self, traceback="w3bsite.Website.stripe")
+		_defaults_.dev0s.defaults.__init__(self, traceback="w3bsite.Website.stripe")
 		self.assign(defaults.dict())
 
 		# arguments.
@@ -61,7 +61,7 @@ class Stripe(_defaults_.Defaults):
 		self.template_data["STRIPE"]["PRODUCTS"] = {}
 
 		# defaults.
-		self.stripe_defaults = self.Defaults(
+		self.stripe_defaults = self.dev0s.defaults.(
 			secret_key=self.secret_key,
 			publishable_key=self.publishable_key,
 			products=self._subscriptions_,
@@ -131,50 +131,50 @@ class Stripe(_defaults_.Defaults):
 			# check product.
 			if not product in product_names:
 				if self.interactive:
-					if Console.input(f"There is no stripe product named {product}. Do you want to create this stripe product? ({self.sandbox_txt})", yes_no=True):
+					if dev0s.console.input(f"There is no stripe product named {product}. Do you want to create this stripe product? ({self.sandbox_txt})", yes_no=True):
 						# create product.
 						response = self.products.create(
 							id=product,
 							description=None,)
-						Response.log(response=response)
+						dev0s.response.log(response=response)
 						edits += 1
 						if not response.success: return response
 					else:
-						return Response.error(f"Aborted.")
+						return dev0s.response.error(f"Aborted.")
 				else:
-					return Response.error(f"Stripe product {product} does not exist.")
+					return dev0s.response.error(f"Stripe product {product} does not exist.")
 
 			# iterate plans.
 			for plan_name, plan_info in plans.items():
 
 				# check plan info.
 				try: plan_info["price"]
-				except KeyError: return Response.error(f"Invalid <Website.stripe_products> parameter. Stripe plan {plan_name} from product {product} does not contain a price value.")
+				except KeyError: return dev0s.response.error(f"Invalid <Website.stripe_products> parameter. Stripe plan {plan_name} from product {product} does not contain a price value.")
 				try: plan_info["currency"]
-				except KeyError: return Response.error(f"Invalid <Website.stripe_products> parameter. Stripe plan {plan_name} from product {product} does not contain a currency value.")
+				except KeyError: return dev0s.response.error(f"Invalid <Website.stripe_products> parameter. Stripe plan {plan_name} from product {product} does not contain a currency value.")
 
 				# check plan.
 				if product not in list(plan_names.keys()) or plan_name not in plan_names[product]:
 					if self.interactive:
-						if Console.input(f"There is no stripe plan named {plan_name} for product {product}. Do you want to create this stripe plan? ({self.sandbox_txt})", yes_no=True):
+						if dev0s.console.input(f"There is no stripe plan named {plan_name} for product {product}. Do you want to create this stripe plan? ({self.sandbox_txt})", yes_no=True):
 							# create product.
 							response = self.plans.create(
 								id=plan_name,
 								product=product,
 								price=plan_info["price"],
 								currency=plan_info["currency"],)
-							Response.log(response=response)
+							dev0s.response.log(response=response)
 							edits += 1
 							if not response.success: return response
 						else:
-							return Response.error(f"Aborted.")
+							return dev0s.response.error(f"Aborted.")
 					else:
-						return Response.error(f"Stripe product {product} does not exist.")
+						return dev0s.response.error(f"Stripe product {product} does not exist.")
 
 				# check plan price change.
 				elif plan_info["price"] != products[product_ids[product]]["plans"][plan_ids[product][plan_name]]["price"]:
 					# handle soon.
-					return Response.error(f'Price change in product {product} plan {plan_name}, previous price: {products[product_ids[product]]["plans"][plan_ids[product][plan_name]]["price"]}, new price: {plan_info["price"]}.')
+					return dev0s.response.error(f'Price change in product {product} plan {plan_name}, previous price: {products[product_ids[product]]["plans"][plan_ids[product][plan_name]]["price"]}, new price: {plan_info["price"]}.')
 				
 
 		# add plan id to tempalte data.
@@ -187,7 +187,7 @@ class Stripe(_defaults_.Defaults):
 			self.template_data["STRIPE"]["PRODUCTS"][product] = {}
 			for plan_name, plan_info in plans.items():
 				try: plan_id = plan_ids[product][plan_name]
-				except KeyError: return Response.error(f"Unable to find the id from plan {plan_name} product {product}.")
+				except KeyError: return dev0s.response.error(f"Unable to find the id from plan {plan_name} product {product}.")
 				try: favicon = plan_info["favicon"]
 				except KeyError: favicon = None
 				self.template_data["STRIPE"]["PRODUCTS"][product][plan_name] = {
@@ -200,45 +200,45 @@ class Stripe(_defaults_.Defaults):
 				}
 
 		# handler.
-		return Response.success(f"Successfully checked the stripe products & plans.")
+		return dev0s.response.success(f"Successfully checked the stripe products & plans.")
 	def get_product_id(self, product=None):
 		try: plan_id = self.product_ids[product]
-		except KeyError: return Response.error(f"Unable to find the id from product {product}.")
-		return Response.success(f"Successfully retrieved the id from product {product}.", {
+		except KeyError: return dev0s.response.error(f"Unable to find the id from product {product}.")
+		return dev0s.response.success(f"Successfully retrieved the id from product {product}.", {
 		 	"id":plan_id,
 		})
 	def get_plan_id(self, product=None, plan=None):
 		try: plan_id = self.plan_ids[product][plan]
-		except KeyError: return Response.error(f"Unable to find the id from plan {plan} product {product}.")
-		return Response.success(f"Successfully retrieved the id from plan {plan} product {product}.", {
+		except KeyError: return dev0s.response.error(f"Unable to find the id from plan {plan} product {product}.")
+		return dev0s.response.success(f"Successfully retrieved the id from plan {plan} product {product}.", {
 		 	"id":plan_id,
 		})
 	def get_product_id_by_plan_id(self, plan_id):
 		for _product_, _plans_ in self._subscriptions_.items():
 			for _plan_name_, plan_info in _plans_.items():
 				if self.plan_ids[_product_][_plan_name_] == plan_id:
-					return Response.success(f"Successfully retrieved the product id of plan id {plan_id}.", {
+					return dev0s.response.success(f"Successfully retrieved the product id of plan id {plan_id}.", {
 						"id":self.product_ids[_product_],
 					})
-		return Response.success(f"Unable to find the the product id of plan id {plan_id}.")
+		return dev0s.response.success(f"Unable to find the the product id of plan id {plan_id}.")
 	def get_product_name(self, id=None):
 		for product, _id_ in self.product_ids.items():
 			if _id_ == id:
-				return Response.success(f"Successfully retrieved the name of product {id}.", {
+				return dev0s.response.success(f"Successfully retrieved the name of product {id}.", {
 				 	"name":product,
 				})
-		return Response.error(f"Unable to find the name of product {id}.")
+		return dev0s.response.error(f"Unable to find the name of product {id}.")
 	def get_plan_name(self, id=None):
 		for product, ids in self.plan_ids.items():
 			for plan, _id_ in ids.items():
 				if _id_ == id:
-					return Response.success(f"Successfully retrieved the name of plan {id}.", {
+					return dev0s.response.success(f"Successfully retrieved the name of plan {id}.", {
 					 	"name":plan,
 					})
-		return Response.error(f"Unable to find the name of plan {id}.")
+		return dev0s.response.error(f"Unable to find the name of plan {id}.")
 
 	# the defaults object.
-	class Defaults(Object):
+	class dev0s.defaults.(Object):
 		def __init__(self,
 			# the stripe secret key.
 			secret_key=None,
@@ -289,7 +289,7 @@ class Stripe(_defaults_.Defaults):
 		):
 
 			# params.
-			response = Response.parameters.check(
+			response = dev0s.response.parameters.check(
 				traceback=self.__traceback__(function="check"),
 				parameters={
 					"email":email,
@@ -307,7 +307,7 @@ class Stripe(_defaults_.Defaults):
 					break
 
 			# handler.
-			return Response.success(f"Successfully checked the stripe customer existsance of user {email}.", {
+			return dev0s.response.success(f"Successfully checked the stripe customer existsance of user {email}.", {
 				"exists":exists,
 				"id":id,
 			})
@@ -317,7 +317,7 @@ class Stripe(_defaults_.Defaults):
 		):
 
 			# params.
-			response = Response.parameters.check(
+			response = dev0s.response.parameters.check(
 				traceback=self.__traceback__(function="create"),
 				parameters={
 					"email":email,
@@ -328,7 +328,7 @@ class Stripe(_defaults_.Defaults):
 			response = self.check(email)
 			if not response.success: return response
 			if response["exists"]:
-				return Response.error(f"User {email} already has a stripe customer [{response['id']}].")
+				return dev0s.response.error(f"User {email} already has a stripe customer [{response['id']}].")
 
 			# request.
 			try:
@@ -340,12 +340,12 @@ class Stripe(_defaults_.Defaults):
 				customer_id = response["id"]
 				success = response["object"] == "customer" and "cus_" in customer_id
 				if not success: raise KeyError("")
-				return Response.success(f"Successfully created a stripe customer for user {email}.", {
+				return dev0s.response.success(f"Successfully created a stripe customer for user {email}.", {
 					"email":email,
 					"id":customer_id,
 				})
 			except KeyError:
-				return Response.error(f"Failed to create stripe customer for user {email}, stripe response: {response}.")
+				return dev0s.response.error(f"Failed to create stripe customer for user {email}, stripe response: {response}.")
 
 			#
 		def delete(self, 
@@ -354,7 +354,7 @@ class Stripe(_defaults_.Defaults):
 		):
 
 			# params.
-			response = Response.parameters.check(
+			response = dev0s.response.parameters.check(
 				traceback=self.__traceback__(function="delete"),
 				parameters={
 					"id":id,
@@ -370,11 +370,11 @@ class Stripe(_defaults_.Defaults):
 			try:
 				success = response["deleted"] == True
 				if not success: raise KeyError("")
-				return Response.success(f"Successfully deleted stripe customer {id}.", {
+				return dev0s.response.success(f"Successfully deleted stripe customer {id}.", {
 					"id":id,
 				})
 			except KeyError:
-				return Response.error(f"Failed to delete stripe customer {id}, stripe response: {response}.")
+				return dev0s.response.error(f"Failed to delete stripe customer {id}, stripe response: {response}.")
 
 			#
 		def get_id(self,
@@ -385,10 +385,10 @@ class Stripe(_defaults_.Defaults):
 			if not response.success: return response
 			for customer_id, info in response.customers.items():
 				if info["email"] == email:
-					return Response.success(f"Successfully retrieved the stripe customer id of user {email}.", {
+					return dev0s.response.success(f"Successfully retrieved the stripe customer id of user {email}.", {
 						"id":customer_id,
 					})
-			return Response.error(f"Unable to find a stripe customer for user {email}.")		
+			return dev0s.response.error(f"Unable to find a stripe customer for user {email}.")		
 		def get(self,
 			# the stripe customer id (optional).
 			id=None,
@@ -407,18 +407,18 @@ class Stripe(_defaults_.Defaults):
 			if id == None:
 				
 				# success.
-				return Response.success(f"Successfully retrieved {len(customers)} customer(s).", {
+				return dev0s.response.success(f"Successfully retrieved {len(customers)} customer(s).", {
 					"customers":customers,
 				})
 
 			# by id.
 			else:
 				try:
-					return Response.success(f"Successfully retrieved the customer [{id}].", {
+					return dev0s.response.success(f"Successfully retrieved the customer [{id}].", {
 						"customer":customers[id],
 					})
 				except KeyError:
-					return Response.error(f"Unable to find customer [{id}].")
+					return dev0s.response.error(f"Unable to find customer [{id}].")
 
 			#
 		def get_cards(self, 
@@ -427,7 +427,7 @@ class Stripe(_defaults_.Defaults):
 		):
 
 			# params.
-			response = Response.parameters.check(
+			response = dev0s.response.parameters.check(
 				traceback=self.__traceback__(function="get_cards"),
 				parameters={
 				"id":id,})
@@ -446,7 +446,7 @@ class Stripe(_defaults_.Defaults):
 			try:
 				data = response["data"]
 			except KeyError:
-				return Response.error(f"Failed to retrieve the cards of user {id}, stripe response: {response}.")
+				return dev0s.response.error(f"Failed to retrieve the cards of user {id}, stripe response: {response}.")
 
 			# serialize.
 			cards = {}
@@ -462,7 +462,7 @@ class Stripe(_defaults_.Defaults):
 				cards[item["id"]] = item
 
 			# success.
-			return Response.success(f"Successfully listed {len(cards)} card(s) of user {id}.", {
+			return dev0s.response.success(f"Successfully listed {len(cards)} card(s) of user {id}.", {
 				"cards":cards,
 			})
 
@@ -483,7 +483,7 @@ class Stripe(_defaults_.Defaults):
 		):
 
 			# params.
-			response = Response.parameters.check(
+			response = dev0s.response.parameters.check(
 				traceback=self.__traceback__(function="create_card"),
 				parameters={
 					"id":id,
@@ -517,7 +517,7 @@ class Stripe(_defaults_.Defaults):
 				success = token["object"] == "token" and "tok_" in token_id
 				if not success: raise KeyError("")
 			except KeyError:
-				return Response.error(f"Failed to create a card for user {id}, stripe response: {token}.")
+				return dev0s.response.error(f"Failed to create a card for user {id}, stripe response: {token}.")
 
 			# create request.
 			if len(cards) == 0:
@@ -536,7 +536,7 @@ class Stripe(_defaults_.Defaults):
 					success = response["deleted"] == True
 					if not success: raise KeyError("")
 				except KeyError:
-					return Response.error(f"Failed to delete card {card} from user {id}, stripe response: {response}.")
+					return dev0s.response.error(f"Failed to delete card {card} from user {id}, stripe response: {response}.")
 
 				# create.
 				try:
@@ -548,13 +548,13 @@ class Stripe(_defaults_.Defaults):
 				card_id = response["id"]
 				success = response["object"] == "card" and "card_" in card_id
 				if not success: raise KeyError("")
-				return Response.success(f"Successfully saved payment method ************{response['last4']}.", {
+				return dev0s.response.success(f"Successfully saved payment method ************{response['last4']}.", {
 					"customer_id":id,
 					"card_id":card_id,
 					#"source_id":"@@"
 				})
 			except KeyError:
-				return Response.error(f"Failed to create a card for user {id}, stripe response: {response}.")
+				return dev0s.response.error(f"Failed to create a card for user {id}, stripe response: {response}.")
 
 			#
 		def delete_card(self, 
@@ -563,7 +563,7 @@ class Stripe(_defaults_.Defaults):
 		):
 			
 			# params.
-			response = Response.parameters.check(
+			response = dev0s.response.parameters.check(
 				traceback=self.__traceback__(function="delete_card"),
 				parameters={
 					"id":id,
@@ -574,7 +574,7 @@ class Stripe(_defaults_.Defaults):
 			response = self.get_cards(id=id)
 			if not response.success: return response
 			if len(response.cards) == 0:
-				return Response.error("There are no payment methods stored.")
+				return dev0s.response.error("There are no payment methods stored.")
 			card = list(response.cards,keys())[0]
 
 			# delete request.
@@ -586,11 +586,11 @@ class Stripe(_defaults_.Defaults):
 			try:
 				success = response["deleted"] == True
 				if not success: raise KeyError("")
-				return Response.success(f"Successfully deleted card {id}.", {
+				return dev0s.response.success(f"Successfully deleted card {id}.", {
 					"card_id":card_id,
 				})
 			except KeyError:
-				return Response.error(f"Failed to delete card {card} from user {id}, stripe response: {response}.")
+				return dev0s.response.error(f"Failed to delete card {card} from user {id}, stripe response: {response}.")
 
 	# the subscriptions object.
 	class Subscriptions(Object):
@@ -619,8 +619,8 @@ class Stripe(_defaults_.Defaults):
 		):
 
 			# params.
-			if email == None and customer_id == None: return Response.error("Specify one of the following parameters: [email, customer_id].")
-			if not isinstance(plans, list): return Response.error("The plans <website.stripe.subscriptions.create:plans> parameter requires to be a list.")
+			if email == None and customer_id == None: return dev0s.response.error("Specify one of the following parameters: [email, customer_id].")
+			if not isinstance(plans, list): return dev0s.response.error("The plans <website.stripe.subscriptions.create:plans> parameter requires to be a list.")
 
 			# get customer id.
 			if customer_id == None:
@@ -644,11 +644,11 @@ class Stripe(_defaults_.Defaults):
 				subscription_id = response["id"]
 				success = response["object"] == "subscription" and response["status"] == "active"
 				if not success: raise KeyError("")
-				return Response.success(f"Successfully created subscription {id}.", {
+				return dev0s.response.success(f"Successfully created subscription {id}.", {
 					"id":subscription_id,
 				})
 			except KeyError:
-				return Response.error(f"Failed to create subscription {id}, stripe response: {response}.")
+				return dev0s.response.error(f"Failed to create subscription {id}, stripe response: {response}.")
 
 			#
 		def get(self, 
@@ -705,22 +705,22 @@ class Stripe(_defaults_.Defaults):
 			if email == None:
 				
 				# success.
-				return Response.success("Successfully retrieved the subscriptions.", {
+				return dev0s.response.success("Successfully retrieved the subscriptions.", {
 					"subscriptions":subscriptions,
 				})
 
 			# by email.
 			else:
 				try:
-					return Response.success(f"Successfully retrieved the subscriptions of user [{email}].", {
+					return dev0s.response.success(f"Successfully retrieved the subscriptions of user [{email}].", {
 						"subscriptions":subscriptions[email],
 					})
 				except KeyError:
-					return Response.error(f"No subscriptions found for user [{email}].")
+					return dev0s.response.error(f"No subscriptions found for user [{email}].")
 
 			# error.
 			#except Exception as e:
-			#	return Response.error(f"Failed to retrieve the subscriptions, error: {e}.")
+			#	return dev0s.response.error(f"Failed to retrieve the subscriptions, error: {e}.")
 
 			#
 		def cancel(self, 
@@ -736,7 +736,7 @@ class Stripe(_defaults_.Defaults):
 			
 			# check options.
 			if subscription_id == None and (email == None or plan == None):
-				return Response.error(f"Define option 1 parameter [subscription_id], option 2: parameters [email, plan].")	
+				return dev0s.response.error(f"Define option 1 parameter [subscription_id], option 2: parameters [email, plan].")	
 
 			# get subscription id.
 			if subscription_id == None:
@@ -747,7 +747,7 @@ class Stripe(_defaults_.Defaults):
 						subscription_id = _subscription_id_
 						break
 				if subscription_id == None:
-					return Response.error(f"Unable to find any subscriptions for user {email} plan {plan}.")	
+					return dev0s.response.error(f"Unable to find any subscriptions for user {email} plan {plan}.")	
 
 			# delete.
 			try:
@@ -757,12 +757,12 @@ class Stripe(_defaults_.Defaults):
 
 			# handle success.
 			if success == True:
-				return Response.success(f"Successfully canceled the subscription for user [{email}] from plan [{plan}].")
+				return dev0s.response.success(f"Successfully canceled the subscription for user [{email}] from plan [{plan}].")
 			else:
 				if isinstance(success, str):
-					return Response.error(f"Failed to cancel the subscription for user [{email}] from plan [{plan}], error: {success}.")
+					return dev0s.response.error(f"Failed to cancel the subscription for user [{email}] from plan [{plan}], error: {success}.")
 				else:
-					return Response.error(f"Failed to cancel the subscription for user [{email}] from plan [{plan}]")
+					return dev0s.response.error(f"Failed to cancel the subscription for user [{email}] from plan [{plan}]")
 
 			#
 	
@@ -802,7 +802,7 @@ class Stripe(_defaults_.Defaults):
 			try:
 				data = response["data"]
 			except KeyError:
-				return Response.error(f"Failed to retrieve the plans, stripe response: {response}.")
+				return dev0s.response.error(f"Failed to retrieve the plans, stripe response: {response}.")
 
 			# get subscriptions.
 			subscriptions = {}
@@ -828,21 +828,21 @@ class Stripe(_defaults_.Defaults):
 					item["price"] = item["unit_amount"]/100 # round(item["unit_amount"]/100,2)
 					plans[item["id"]] = item
 			else: 
-				return Response.error(f"Failed to retrieve the plans, unkown data instance, data: {data}.")
+				return dev0s.response.error(f"Failed to retrieve the plans, unkown data instance, data: {data}.")
 
 			# by no id.
 			if id == None:
-				return Response.success(f"Successfully listed {len(plans)} plan(s).", {
+				return dev0s.response.success(f"Successfully listed {len(plans)} plan(s).", {
 					"plans":plans,
 				})
 			# by id.
 			else:
 				try:
-					return Response.success(f"Successfully listed the plan {id}.", {
+					return dev0s.response.success(f"Successfully listed the plan {id}.", {
 						"plans":plans[id],
 					})
 				except KeyError:
-					return Response.error(f"Unable to find plan {id}.")
+					return dev0s.response.error(f"Unable to find plan {id}.")
 		def create(self,
 			# the plan id.
 			id=None,
@@ -857,7 +857,7 @@ class Stripe(_defaults_.Defaults):
 		):
 
 			# params.
-			response = Response.parameters.check(
+			response = dev0s.response.parameters.check(
 				traceback=self.__traceback__(function="create"),
 				parameters={
 					"id":id,
@@ -883,7 +883,7 @@ class Stripe(_defaults_.Defaults):
 				plan_id = response["id"]
 				success = response["active"] == True
 				if not success: raise KeyError("")
-				return Response.success(f"Successfully created product {id}.", {
+				return dev0s.response.success(f"Successfully created product {id}.", {
 					"name":id,
 					"id":plan_id,
 					"price":price,
@@ -891,7 +891,7 @@ class Stripe(_defaults_.Defaults):
 					"product":product,
 				})
 			except KeyError:
-				return Response.error(f"Failed to create product {id}, stripe response: {response}.")
+				return dev0s.response.error(f"Failed to create product {id}, stripe response: {response}.")
 
 	# the products object.
 	class Products(Object):
@@ -931,7 +931,7 @@ class Stripe(_defaults_.Defaults):
 			try:
 				data = response["data"]
 			except KeyError:
-				return Response.error(f"Failed to retrieve the products, stripe response: {response}.")
+				return dev0s.response.error(f"Failed to retrieve the products, stripe response: {response}.")
 
 			# get plans.
 			plans = {}
@@ -952,21 +952,21 @@ class Stripe(_defaults_.Defaults):
 						item["plans"] = product_plans
 					products[item["id"]] = item
 			else: 
-				return Response.error(f"Failed to retrieve the products, unkown data instance, data: {data}.")
+				return dev0s.response.error(f"Failed to retrieve the products, unkown data instance, data: {data}.")
 
 			# by no id.
 			if id == None:
-				return Response.success(f"Successfully listed {len(products)} product(s).", {
+				return dev0s.response.success(f"Successfully listed {len(products)} product(s).", {
 						"products":products,
 					})
 			# by id.
 			else:
 				try:
-					return Response.success(f"Successfully listed the product {id}.", {
+					return dev0s.response.success(f"Successfully listed the product {id}.", {
 						"products":products[id],
 					})
 				except KeyError:
-					return Response.error(f"Unable to find product {id}.")
+					return dev0s.response.error(f"Unable to find product {id}.")
 		def create(self,
 			# the product id.
 			id=None,
@@ -975,7 +975,7 @@ class Stripe(_defaults_.Defaults):
 		):
 			
 			# params.
-			response = Response.parameters.check(
+			response = dev0s.response.parameters.check(
 				traceback=self.__traceback__(function="create"),
 				parameters={
 					"id":id,
@@ -997,12 +997,12 @@ class Stripe(_defaults_.Defaults):
 				id = response["id"]
 				success = response["active"] == True
 				if not success: raise KeyError("")
-				return Response.success(f"Successfully created product {id}.", {
+				return dev0s.response.success(f"Successfully created product {id}.", {
 					"name":id,
 					"id":id,
 				})
 			except KeyError:
-				return Response.error(f"Failed to create product {id}, stripe response: {response}.")
+				return dev0s.response.error(f"Failed to create product {id}, stripe response: {response}.")
 
 
 	#
\ No newline at end of file
